@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package YAML::PP::Representer;
 
-our $VERSION = '0.033_001'; # TRIAL VERSION
+our $VERSION = '0.033_002'; # TRIAL VERSION
 
 use Scalar::Util qw/ reftype blessed refaddr /;
 
@@ -131,6 +131,15 @@ sub represent_node {
 
 }
 
+my $bool_code = <<'EOM';
+sub {
+    my ($x) = @_;
+    use experimental qw/ builtin /;
+    builtin::is_bool($x);
+}
+EOM
+my $is_bool;
+
 sub represent_node_nonref {
     my ($self, $node) = @_;
     my $representers = $self->schema->representers;
@@ -145,6 +154,12 @@ sub represent_node_nonref {
             return 1;
         }
     }
+    if ($] >= 5.036000 and my $rep = $representers->{bool}) {
+        $is_bool ||= eval $bool_code;
+        if ($is_bool->($node->{value})) {
+            return $rep->{code}->($self, $node);
+        }
+    }
     for my $rep (@{ $representers->{flags} }) {
         my $check_flags = $rep->{flags};
         my $flags = B::svref_2object(\$node->{value})->FLAGS;
